#!/usr/bin/env python3

#******************************************************************************
# optiondefaults.py, defines defaults for config options
#
# TreeLine, an information storage program
# Copyright (C) 2014, Douglas W. Bell
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License, either Version 2 or any later
# version.  This program is distributed in the hope that it will be useful,
# but WITTHOUT ANY WARRANTY.  See the included LICENSE file for details.
#******************************************************************************

import options


daysOfWeek = ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday',
               'Saturday', 'Sunday']


def setGenOptionDefaults(generalOptions):
    """Set defaults for general config options.
    """
    StringOptionItem = options.StringOptionItem
    IntOptionItem = options.IntOptionItem
    BoolOptionItem = options.BoolOptionItem
    ListOptionItem = options.ListOptionItem
    BoolOptionItem(generalOptions, 'AutoFileOpen', False, 'Startup Condition',
                   'Automatically open last file used')
    BoolOptionItem(generalOptions, 'ShowChildPane', True, 'Startup Condition',
                   'Show child pane in right hand view')
    BoolOptionItem(generalOptions, 'ShowDescendants', False,
                   'Startup Condition', 'Show descendants in output view')
    BoolOptionItem(generalOptions, 'SaveTreeStates', True, 'Startup Condition',
                   'Restore tree view states of recent files')
    BoolOptionItem(generalOptions, 'SaveWindowGeom', True, 'Startup Condition',
                   'Restore previous window geometry')
    BoolOptionItem(generalOptions, 'OpenNewWindow', True, 'Features Available',
                   'Open files in new windows')
    BoolOptionItem(generalOptions, 'ClickRename', True, 'Features Available',
                   'Click node to rename')
    BoolOptionItem(generalOptions, 'RenameNewNodes', True,
                   'Features Available', 'Rename new nodes when created')
    BoolOptionItem(generalOptions, 'DragTree', True, 'Features Available',
                   'Tree drag && drop available')
    BoolOptionItem(generalOptions, 'ShowTreeIcons', True, 'Features Available',
                   'Show icons in the tree view')
    BoolOptionItem(generalOptions, 'ShowUniqueID', False, 'Features Available',
                   'Show node unique IDs in the Data Edit view')
    BoolOptionItem(generalOptions, 'EditNumbering', False,
                   'Features Available',
                   'Show numbering fields in the Data Edit view')
    IntOptionItem(generalOptions, 'UndoLevels', 5, 0, 999, 'Undo Memory',
                  'Number of undo levels', 1)
    IntOptionItem(generalOptions, 'AutoSaveMinutes', 0, 0, 999, 'Auto Save',
                  'Minutes between saves\n(set to 0 to disable)', 1)
    IntOptionItem(generalOptions, 'RecentFiles', 4, 0, 99, 'Recent Files',
                  'Number of recent files \nin the file menu', 1)
    StringOptionItem(generalOptions, 'EditTimeFormat', 'H:mm:ss', False,
                     'Data Editor Formats', 'Times', 1)
    StringOptionItem(generalOptions, 'EditDateFormat', 'MM/dd/yy', False,
                     'Data Editor Formats', 'Dates', 1)
    ListOptionItem(generalOptions, 'WeekStart', daysOfWeek[-1], daysOfWeek,
                   'Data Editor Formats', 'First day\nof week', 1)
    IntOptionItem(generalOptions, 'IndentOffset', 2, 0, 99, 'Appearance',
                  'Child indent offset\n(in font height units) ', 1)

def setMiscOptionDefaults(miscOptions):
    """Set defaults for miscellaneous config options.
    """
    StringOptionItem = options.StringOptionItem
    StringOptionItem(miscOptions, 'PrintUnits', 'in', False,
                     'Printer Settings')
    StringOptionItem(miscOptions, 'SpellCheckPath', '', True, 'Spell Check')
    StringOptionItem(miscOptions, 'TreeFont', '', True, 'Fonts')
    StringOptionItem(miscOptions, 'OutputFont', '', True, 'Fonts')
    StringOptionItem(miscOptions, 'EditorFont', '', True, 'Fonts')

def setHistOptionDefaults(historyOptions):
    """Set defaults for history config options.
    """
    StringOptionItem = options.StringOptionItem
    IntOptionItem = options.IntOptionItem
    IntOptionItem(historyOptions, 'WindowXSize', 640, 10, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'WindowYSize', 640, 10, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'WindowXPos', -1000, -1000, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'WindowYPos', -1000, -1000, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'TreeSplitPercent', 40, 1, 99,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'OutputSplitPercent', 20, 1, 99,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'EditorSplitPercent', 25, 1, 99,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'TitleSplitPercent', 10, 1, 99,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'ActiveRightView', 0, 0, 2,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'PrintPrevXSize', 0, 0, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'PrintPrevYSize', 0, 0, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'PrintPrevXPos', -1000, -1000, 10000,
                  'Window Geometry')
    IntOptionItem(historyOptions, 'PrintPrevYPos', -1000, -1000, 10000,
                  'Window Geometry')

def setToolbarOptionDefaults(toolbarOptions):
    """Set defaults for toolbar geometry and buttons.
    """
    StringOptionItem = options.StringOptionItem
    IntOptionItem = options.IntOptionItem
    IntOptionItem(toolbarOptions, 'ToolbarQuantity', 2, 0, 20,
                  'Toolbar Geometry')
    IntOptionItem(toolbarOptions, 'ToolbarSize', 16, 1, 128,
                  'Toolbar Geometry')
    StringOptionItem(toolbarOptions, 'ToolbarPosition', '', True,
                     'Toolbar Geometry')
    StringOptionItem(toolbarOptions, 'Toolbar0',
                     'FileNew,FileOpen,FileSave,,FilePrintPreview,FilePrint,,'
                     'EditUndo,EditRedo,,EditCut,EditCopy,EditPaste,,'
                     'DataConfigType', True, 'Toolbar Commands')
    StringOptionItem(toolbarOptions, 'Toolbar1',
                     'NodeInsertAfter,NodeAddChild,,NodeDelete,NodeIndent,'
                     'NodeUnindent,,NodeMoveUp,NodeMoveDown,,'
                     'ViewPrevSelect,ViewNextSelect,,ViewShowDescend',
                     True, 'Toolbar Commands')

def setKeyboardOptionDefaults(keyboardOptions):
    """Set defaults for keyboard shortcuts.
    """
    KeyOptionItem = options.KeyOptionItem
    KeyOptionItem(keyboardOptions, 'FileNew', 'Ctrl+N', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileOpen', 'Ctrl+O', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileOpenSample', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileImport', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileSave', 'Ctrl+S', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileSaveAs', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileExport', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileProperties', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FilePrintSetup', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FilePrintPreview', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FilePrint', 'Ctrl+P', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FilePrintPdf', '', 'File Menu')
    KeyOptionItem(keyboardOptions, 'FileQuit', 'Ctrl+Q', 'File Menu')
    KeyOptionItem(keyboardOptions, 'EditUndo', 'Ctrl+Z', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditRedo', 'Ctrl+Y', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditCut', 'Ctrl+X', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditCopy', 'Ctrl+C', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditPaste', 'Ctrl+V', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditPastePlain', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditBoldFont', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditItalicFont', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditUnderlineFont', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditFontSize', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditFontColor', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditExtLink', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'EditIntLink', '', 'Edit Menu')
    KeyOptionItem(keyboardOptions, 'NodeRename', 'Ctrl+R', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeInsertBefore', 'Ctrl+B', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeInsertAfter', 'Ctrl+I', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeAddChild', 'Ctrl+A', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeDelete', 'Del', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeIndent', 'Ctrl+Shift+Right',
                  'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeUnindent', 'Ctrl+Shift+Left',
                  'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeMoveUp', 'Ctrl+Shift+Up', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeMoveDown', 'Ctrl+Shift+Down',
                  'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeMoveFirst', '', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'NodeMoveLast', '', 'Node Menu')
    KeyOptionItem(keyboardOptions, 'DataNodeType', 'Ctrl+T', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataConfigType', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataCopyType', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataSortNodes', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataNumbering', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataFlatCategory', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataAddCategory', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataFlatLink', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'DataArrangeLink', '', 'Data Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFindText', 'Ctrl+F', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFindCondition', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFindReplace', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFilterText', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFilterCondition', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsSpellCheck', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsGenOptions', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsShortcuts', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsToolbars', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ToolsFonts', '', 'Tools Menu')
    KeyOptionItem(keyboardOptions, 'ViewExpandBranch', 'Ctrl+Right',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewCollapseBranch', 'Ctrl+Left',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewPrevSelect', 'Ctrl+Shift+P',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewNextSelect', 'Ctrl+Shift+N',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewDataOutput', 'Ctrl+Shift+O',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewDataEditor', 'Ctrl+Shift+E',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewTitleList', 'Ctrl+Shift+T',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewShowChildPane', 'Ctrl+Shift+C',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'ViewShowDescend', 'Ctrl+Shift+D',
                  'View Menu')
    KeyOptionItem(keyboardOptions, 'WinNewWindow', '', 'Window Menu')
    KeyOptionItem(keyboardOptions, 'WinCloseWindow', '', 'Window Menu')
    KeyOptionItem(keyboardOptions, 'HelpBasic', '', 'Help Menu')
    KeyOptionItem(keyboardOptions, 'HelpFull', '', 'Help Menu')
    KeyOptionItem(keyboardOptions, 'HelpAbout', '', 'Help Menu')
